@@ -7,12 +7,11 @@ sys.path.insert(0, os.path.abspath(os.path.join(os.path.dirname(__file__), "../u
 # Import the required classes and functions
 # pylint: disable=unused-import,wrong-import-position
 from up42.tools import Tools
+from up42.viztools import folium_base_map, VizTools
 from up42.utils import (
-    folium_base_map,
     any_vector_to_fc,
     fc_to_query_geometry,
     download_results_from_gcs,
-    _map_images,
     filter_jobs_on_mode,
 )
 from up42.auth import Auth
