@@ -1,26 +1,23 @@
+"""
+Base functionality that is not bound to a specific higher level UP42 object.
+"""
+
 import json
 from pathlib import Path
-from typing import Tuple, List, Union, Dict
+from typing import List, Union, Dict
 import warnings
 
 from geopandas import GeoDataFrame
 import geopandas as gpd
-import matplotlib.pyplot as plt
 import pandas as pd
 import shapely
-import rasterio
-import folium
 
+from up42.viztools import folium_base_map, DrawFoliumOverride
 from up42.utils import (
     get_logger,
-    folium_base_map,
-    DrawFoliumOverride,
-    _plot_images,
-    _map_images,
 )
 
 try:
-    from IPython.display import display
     from IPython import get_ipython
 
     get_ipython().run_line_magic("matplotlib", "inline")
@@ -35,15 +32,34 @@ logger = get_logger(__name__)
 class Tools:
     def __init__(self, auth=None):
         """
-        The tools class contains functionality that is not bound to a specific UP42 object,
-        e.g. for aoi handling etc., UP42 block information, validatin a block manifest etc.
-        They can be accessed from every object and also from the imported up42 package directly.
+        The tools class contains the base functionality that is not bound to a specific
+        higher level UP42 object.
         """
         if auth:
             self.auth = auth
         self.quicklooks = None
         self.results = None
 
+    def _deprecate_tools(self, function_name: str):
+        # TODO: When finally deprecating this, move the functions that don't require
+        # TODO: the class out of it and import directly in init. Don't need to be
+        # TODO: instatiated via Tools in __init__.
+
+        object_name = self.__class__.__name__
+        if object_name in [
+            "Project",
+            "Workflow",
+            "Job",
+            "JobTask",
+            "JobCollection",
+            "Catalog",
+        ]:
+            message = (
+                f"Use of {object_name}.{function_name} will be deprecated in "
+                f"version 0.14.0, use up42.{function_name} instead!"
+            )
+            warnings.warn(message, DeprecationWarning, stacklevel=3)
+
     # pylint: disable=no-self-use
     def read_vector_file(
         self, filename: str = "aoi.geojson", as_dataframe: bool = False
@@ -62,6 +78,8 @@ class Tools:
         Returns:
             Feature Collection
         """
+        self._deprecate_tools("read_vector_file")
+
         suffix = Path(filename).suffix
 
         if suffix == ".kml":
@@ -99,6 +117,8 @@ class Tools:
         Returns:
             Feature collection json with the selected aoi.
         """
+        self._deprecate_tools("get_example_aoi")
+
         logger.info(f"Getting small example aoi in location '{location}'.")
         if location == "Berlin":
             example_aoi = self.read_vector_file(
@@ -128,6 +148,7 @@ class Tools:
         Export the drawn aoi via the export button, then read the geometries via
         read_aoi_file().
         """
+        self._deprecate_tools("draw_aoi")
         m = folium_base_map(layer_control=True)
         DrawFoliumOverride(
             export=True,
@@ -143,160 +164,8 @@ class Tools:
             },
             edit_options={"polygon": {"allowIntersection": False}},
         ).add_to(m)
-
-        try:
-            assert get_ipython() is not None
-            display(m)
-        except (AssertionError, NameError):
-            logger.info(
-                "Returning folium map object. To display it directly run in a "
-                "Jupyter notebook!"
-            )
-            return m
-
-    @staticmethod
-    def plot_coverage(
-        scenes: GeoDataFrame,
-        aoi: GeoDataFrame = None,
-        legend_column: str = "scene_id",
-        figsize=(12, 16),
-    ) -> None:
-        """
-        Plots a coverage map of a dataframe with geometries e.g. the results of catalog.search())
-        Args:
-            scenes: GeoDataFrame of scenes, results of catalog.search()
-            aoi: GeoDataFrame of aoi.
-            legend_column: Dataframe column set to legend, default is "scene_id".
-                Legend entries are sorted and this determines plotting order.
-            figsize: Matplotlib figure size.
-        """
-        if legend_column not in scenes.columns:
-            legend_column = None  # type: ignore
-            logger.info(
-                "Given legend_column name not in scene dataframe, "
-                "plotting without legend."
-            )
-
-        ax = scenes.plot(
-            legend_column,
-            categorical=True,
-            figsize=figsize,
-            cmap="Set3",
-            legend=True,
-            alpha=0.7,
-            legend_kwds=dict(loc="upper left", bbox_to_anchor=(1, 1)),
-        )
-        if aoi is not None:
-            aoi.plot(color="r", ax=ax, fc="None", edgecolor="r", lw=1)
-        ax.set_axis_off()
-        plt.show()
-
-    def plot_quicklooks(
-        self,
-        figsize: Tuple[int, int] = (8, 8),
-        filepaths: List = None,
-        titles: List[str] = None,
-    ) -> None:
-        """
-        Plots the downloaded quicklooks (filepaths saved to self.quicklooks of the
-        respective object, e.g. job, catalog).
-
-        Args:
-            figsize: matplotlib figure size.
-            filepaths: Paths to images to plot. Optional, by default picks up the last
-                downloaded results.
-            titles: List of titles for the subplots, optional.
-
-        """
-        if filepaths is None:
-            if self.quicklooks is None:
-                raise ValueError("You first need to download the quicklooks!")
-            filepaths = self.quicklooks
-
-        plot_file_format = [".jpg", ".jpeg", ".png"]
-        warnings.filterwarnings(
-            "ignore", category=rasterio.errors.NotGeoreferencedWarning
-        )
-        _plot_images(
-            plot_file_format=plot_file_format,
-            figsize=figsize,
-            filepaths=filepaths,
-            titles=titles,
-        )
-
-    def map_quicklooks(
-        self,
-        scenes: GeoDataFrame,
-        aoi: GeoDataFrame = None,
-        filepaths: List = None,
-        name_column: str = "id",
-        save_html: Path = None,
-    ) -> folium.Map:
-        """
-        Plots the downloaded quicklooks (filepaths saved to self.quicklooks of the
-        respective object, e.g. job, catalog).
-
-        Args:
-            scenes: GeoDataFrame of scenes, results of catalog.search()
-            aoi: GeoDataFrame of aoi.
-            filepaths: Paths to images to plot. Optional, by default picks up the last
-                downloaded results.
-            name_column: Name of the feature property that provides the Feature/Layer name.
-            save_html: The path for saving folium map as html file. With default None, no file is saved.
-        """
-        if filepaths is None:
-            if self.quicklooks is None:
-                raise ValueError("You first need to download the quicklooks!")
-            filepaths = self.quicklooks
-
-        plot_file_format = [".jpg", ".jpeg", ".png"]
-        warnings.filterwarnings(
-            "ignore", category=rasterio.errors.NotGeoreferencedWarning
-        )
-        m = _map_images(
-            plot_file_format=plot_file_format,
-            result_df=scenes,
-            filepaths=filepaths,
-            aoi=aoi,
-            name_column=name_column,
-            save_html=save_html,
-        )
-
         return m
 
-    def plot_results(
-        self,
-        figsize: Tuple[int, int] = (14, 8),
-        filepaths: List[Union[str, Path]] = None,
-        titles: List[str] = None,
-    ) -> None:
-        """
-        Plots the downloaded results data.
-
-        Args:
-            figsize: matplotlib figure size.
-            filepaths: Paths to images to plot. Optional, by default picks up the last
-                downloaded results.
-            titles: Optional list of titles for the subplots.
-        """
-        if filepaths is None:
-            if self.results is None:
-                raise ValueError("You first need to download the results!")
-            filepaths = self.results
-            # Unpack results path dict in case of jobcollection.
-            if isinstance(filepaths, dict):
-                filepaths = [
-                    item for sublist in list(filepaths.values()) for item in sublist  # type: ignore
-                ]
-
-        plot_file_format = [".tif"]  # TODO: Add other fileformats.
-        _plot_images(
-            plot_file_format=plot_file_format,
-            figsize=figsize,
-            filepaths=filepaths,
-            titles=titles,
-        )
-
     def get_blocks(
         self,
         block_type=None,
@@ -315,6 +184,8 @@ class Tools:
             A list of the public blocks and their metadata. Optional a simpler version
             dict.
         """
+        self._deprecate_tools("get_blocks")
+
         try:
             block_type = block_type.lower()
         except AttributeError:
@@ -368,6 +239,8 @@ class Tools:
         Returns:
             A dict of the block details metadata for the specific block.
         """
+        self._deprecate_tools("get_block_details")
+
         if not hasattr(self, "auth"):
             raise Exception(
                 "Requires authentication with UP42, use up42.authenticate()!"
@@ -383,55 +256,21 @@ class Tools:
 
     def validate_manifest(self, path_or_json: Union[str, Path, Dict]) -> Dict:
         """
-        Validates the block manifest, input either manifest json string or filepath.
+        Validates a block manifest json.
+
+        The block manifest is required to build a custom block on UP42 and contains
+        the metadata about the block as well as block input and output capabilities.
+        Also see the
+        [manifest chapter in the UP42 documentation](https://docs.up42.com/reference/block-manifest.html).
 
         Args:
-            path_or_json: The input manifest, either filepath or json string, see example.
+            path_or_json: The input manifest, either a filepath or json string, see example.
 
         Returns:
             A dictionary with the validation results and potential validation errors.
-
-        Example:
-            ```json
-                {
-                    "_up42_specification_version": 2,
-                    "name": "sharpening",
-                    "type": "processing",
-                    "tags": [
-                        "imagery",
-                        "processing"
-                    ],
-                    "display_name": "Sharpening Filter",
-                    "description": "This block enhances the sharpness of a raster
-                        image by applying an unsharp mask filter algorithm.",
-                    "parameters": {
-                        "strength": {"type": "string", "default": "medium"}
-                    },
-                    "machine": {
-                        "type": "large"
-                    },
-                    "input_capabilities": {
-                        "raster": {
-                            "up42_standard": {
-                                "format": "GTiff"
-                            }
-                        }
-                    },
-                    "output_capabilities": {
-                        "raster": {
-                            "up42_standard": {
-                                "format": "GTiff",
-                                "bands": ">",
-                                "sensor": ">",
-                                "resolution": ">",
-                                "dtype": ">",
-                                "processing_level": ">"
-                            }
-                        }
-                    }
-                }
-            ```
         """
+        self._deprecate_tools("validate_manifest")
+
         if isinstance(path_or_json, (str, Path)):
             with open(path_or_json) as src:
                 manifest_json = json.load(src)
