@@ -42,8 +42,7 @@ class Workflow(Tools):
         return (
             f"Workflow(name: {info['name']}, workflow_id: {self.workflow_id}, "
             f"description: {info['description']}, createdAt: {info['createdAt']}, "
-            f"project_name: {info['name']}, "
-            f"workflow_tasks: {self.workflow_tasks}"
+            f"project_id: {self.project_id}, workflow_tasks: {self.workflow_tasks}"
         )
 
     @property
@@ -205,16 +204,11 @@ class Workflow(Tools):
                 [marketplace](https://marketplace.up42.com).
 
         !!! Info
-            Using block ids specifies a specific version of the block that will be added
-            to the workflow. With block names or block display names, the most recent
-            version of a block will always be added.
+            With block names or block display names, the most recent version of a block
+            will always be added. Using block ids specifies a specific version of the
+            block that will be added to the workflow.
 
         Example:
-            ```python
-            input_tasks_simple = ['a2daaab4-196d-4226-a018-a810444dcad1',
-                                  '4ed70368-d4e1-4462-bef6-14e768049471']
-            ```
-
             ```python
             input_tasks = ["sobloo-s2-l1c-aoiclipped", "tiling"]
             ```
@@ -223,6 +217,11 @@ class Workflow(Tools):
             input_tasks = ["Sentinel-2 L1C MSI AOI clipped",
                            "Raster Tiling"]
             ```
+
+            ```python
+            input_tasks = ['a2daaab4-196d-4226-a018-a810444dcad1',
+                           '4ed70368-d4e1-4462-bef6-14e768049471']
+            ```
         """
         # Relevant when non-linear workflows are introduced:
         # Optional:
@@ -331,7 +330,10 @@ class Workflow(Tools):
             Dictionary of constructed input parameters.
         """
         input_parameters = self._get_default_parameters()
-        data_block_name = list(input_parameters.keys())[0]
+        try:
+            data_block_name = list(input_parameters.keys())[0]
+        except IndexError as e:
+            raise ValueError("The Workflow has no workflow tasks.") from e
 
         if order_ids is not None:
             # Needs to be handled in this function(not run_job) as it is only
